@@ -1,7 +1,7 @@
 package Bundle::PDF;
 
 
-our $VERSION = '0.01';
+our $VERSION = '0.02';
 
 
 
@@ -58,7 +58,7 @@ Number::Format
 
 XML::Parser
 
-Pdf::FromHTML
+PDF::FromHTML
 
 PDF::Report
 
@@ -122,6 +122,99 @@ PDF::FDF::Simple
 
 PDF::Xtract
 
+Module::Load
+
+Test::Prereq
+
+Net::FTP
+
+Test::PDF
+
+Business::ReportWriter
+
+XML::Handler::YAWriter
+
+XML::Parser::PerlSAX
+
+PDF::Maki
+
+POSIX
+
+Pod::Pdf
+
+ETL::Pequel
+
+RTF::HTMLConverter
+
+MP3::Info
+
+HTML::TreeBuilder
+
+File::MMagic::XS
+
+File::Extract
+
+Test::Pod
+
+Test::Pod::Coverage
+
+HTML::Parser
+
+HTML::Tagset
+
+HTML::HTMLDoc
+
+Image::ExifTool
+
+URI::Title
+
+Webservice::Trynt::PDF
+
+URI
+
+Module::Pluggable
+
+File::Type
+
+File::Copy
+
+Pod::HtmlPsPdf
+
+DocSet
+
+DBIx::ReportBuilder
+
+DBIx::SearchBuilder
+
+GD::Graph
+
+Chart::Math::Axis
+
+MIME::Base64
+
+GD::Text
+
+IO::File
+
+Archive::Zip
+
+OpenOffice::OOBuilder
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
+
 
 =head2 Description
 
@@ -136,7 +229,7 @@ For PDFLib-Lite. see www.pdflib.com
 
 =head1 AUTHOR
 
-Kevin W. Henwood, E<lt>khen1950fx@aol.com<gt>
+Kevin W. Henwood, <Khen1950fx@aol.com>
 
 =head1 COPYRIGHT AND LICENSE
 
